@@ -347,7 +347,7 @@ struct stack *make_non_breaking()
    return para;
 }
 
-struct para *epub_make_para( char *data, enum paras type, char *last_cue, int scene_no, char *shot, int numbers, int addcont )
+struct para *epub_make_para( char *data, enum paras type, char *last_cue, int scene_no, char *shot, int numbers )
 {
    struct para *pptr;
    int cont = 0;
@@ -359,17 +359,6 @@ struct para *epub_make_para( char *data, enum paras type, char *last_cue, int sc
    pptr->shot = *shot;
    pptr->next = NULL;
 
-   if ( addcont && ( type == CUE || type == LCUE || type == RCUE ) && ( same_cue( data, last_cue )))
-   {
-      ++cont;
-
-      if (( data = add_cont( data )) == NULL )
-      {
-         free( pptr );
-         return NULL;
-      }
-   }
-
    if ( type == IDIALOG && data[ 0 ] == ' ' && data[ 1 ] == '\0' )
       pptr->lines = make_non_breaking();
    else
@@ -405,7 +394,7 @@ struct para *epub_make_para( char *data, enum paras type, char *last_cue, int sc
    return pptr;
 }
 
-struct para *epub_make_para_list( struct tsml *tree, struct meta *meta, char *scenes, int numbers, int addcont )
+struct para *epub_make_para_list( struct tsml *tree, struct meta *meta, char *scenes, int numbers )
 {
    struct tsml *tptr;
    struct para *list = NULL, *pptr = NULL, **prev = NULL;
@@ -477,7 +466,7 @@ struct para *epub_make_para_list( struct tsml *tree, struct meta *meta, char *sc
             {
                if ( scene_no != last_scene + 1 )
                {
-                  if (( pptr = epub_make_para( ellipsis, END, last_cue, 0, shot, 0, 0 )) == NULL )
+                  if (( pptr = epub_make_para( ellipsis, END, last_cue, 0, shot, 0 )) == NULL )
                      goto ERR;
 
                   if ( list == NULL )
@@ -557,7 +546,7 @@ struct para *epub_make_para_list( struct tsml *tree, struct meta *meta, char *sc
       if ( tptr->children->next != NULL || tptr->children->type != DATA )
             break;
 
-      if (( pptr = epub_make_para( tptr->children->data, type, last_cue, scene_no, shot, numbers, addcont )) == NULL )
+      if (( pptr = epub_make_para( tptr->children->data, type, last_cue, scene_no, shot, numbers )) == NULL )
          break;
 
       if ( type == CUE || type == LCUE || type == RCUE )
@@ -1117,7 +1106,7 @@ void add_content( char *root, struct meta *meta, struct para *paras, int cover )
    fclose( file );
 }
 
-void make_ebook( char *scenes, char *root, int numbers, int cover, int addcont )
+void make_ebook( char *scenes, char *root, int numbers, int cover )
 {
    struct meta *meta;
    struct tsml *tree;
@@ -1132,7 +1121,7 @@ void make_ebook( char *scenes, char *root, int numbers, int cover, int addcont )
       return;
    }
 
-   if (( paras = epub_make_para_list( tree, meta, scenes, numbers, addcont )) == NULL )
+   if (( paras = epub_make_para_list( tree, meta, scenes, numbers )) == NULL )
    {
       free_meta( meta );
       free_tsml_tree( tree );
